@@ -29,7 +29,7 @@
 #include <csound.h>
 
 
-#define QCS_VERSION "1.0.0-rc2"
+#define QCS_VERSION "1.1.2"
 
 // Time in milliseconds for widget and console messages updates
 #define QCS_QUEUETIMER_DEFAULT_TIME 50
@@ -100,6 +100,16 @@
 
 #define QDEBUG qDebug() << __FUNCTION__ << ":"
 
+// macros for compatibility problems befor and after Qt 5.14
+
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+    #define ENDL Qt::endl
+    #define SKIP_EMPTY_PARTS Qt::SkipEmptyParts
+#else
+    #define ENDL endl
+    #define SKIP_EMPTY_PARTS QString::SkipEmptyParts
+#endif
+
 
 enum viewMode {
 	VIEW_CSD,
@@ -114,9 +124,10 @@ public:
     QString inArgs;
     QString desc;
     int isFlag;
+    bool isInstalled;
 
-    Opcode() {};
-    Opcode(QString name, QString outs="", QString ins=""): opcodeName(name), outArgs(outs), inArgs(ins) {}
+    Opcode() = default;
+    Opcode(QString name, QString outs="", QString ins="", bool installed=true): opcodeName(name), outArgs(outs), inArgs(ins), isInstalled(installed) {}
 
 };
 
@@ -124,16 +135,13 @@ class RingBuffer
 {
 public:
     RingBuffer() {
-        // size = 2048*4;
         size = 4096 * 4;
 		resize(size);
 		currentPos = 0;
 		currentReadPos = 0;
-		//       lock = false;
-	}
-	~RingBuffer() {}
-	//     bool lock;
-	QList<MYFLT> buffer;
+    }
+    ~RingBuffer() = default;
+    QList<MYFLT> buffer;
 	long currentPos;
 	long currentReadPos;
 	int size;
@@ -172,21 +180,6 @@ public:
 		mutex.unlock();
 	}
 
-    void putMany(MYFLT *data, long dataSize) {
-        long space = availableWriteSpace();
-        if(dataSize >= space) {
-            // qDebug("RingBuffer: Buffer overflow, only writing %ld elements!", space);
-            currentReadPos = currentPos;
-        }
-
-        mutex.lock();
-        for(int i=0; i<dataSize; i++) {
-            buffer[currentPos] = data[i];
-            currentPos = (currentPos + 1) % size;
-        }
-        mutex.unlock();
-    }
-
     void putManyScaled(MYFLT *data, long dataSize, MYFLT scaleFactor) {
         long space = availableWriteSpace();
         if(dataSize >= space) {
@@ -194,9 +187,16 @@ public:
             currentReadPos = currentPos;
         }
         mutex.lock();
-        for(int i=0; i<dataSize; i++) {
-            int idx = (currentPos + i) % size;
-            buffer[idx] = data[i] * scaleFactor;
+        if(scaleFactor != 1.0) {
+            for(int i=0; i<dataSize; i++) {
+                int idx = (currentPos + i) % size;
+                buffer[idx] = data[i] * scaleFactor;
+            }
+        } else {
+            for(int i=0; i<dataSize; i++) {
+                int idx = (currentPos + i) % size;
+                buffer[idx] = data[i];
+            }
         }
         auto previousPos = currentPos;
         currentPos += dataSize;
